==> verticalpodautoscaler-model-v1-5.10.1-sources.jar: annotations/io/fabric8/verticalpodautoscaler/api/model/v1/RecommendedPodResourcesFluentImpl.java <==
package io.fabric8.verticalpodautoscaler.api.model.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public class RecommendedPodResourcesFluentImpl<A extends io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedPodResourcesFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedPodResourcesFluent<A>{
  public RecommendedPodResourcesFluentImpl() {
  }
  public RecommendedPodResourcesFluentImpl(io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedPodResources instance) {
    this.withContainerRecommendations(instance.getContainerRecommendations()); 
  }
  private java.util.List<io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder> containerRecommendations;
  public A addToContainerRecommendations(java.lang.Integer index,io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources item) {
    if (this.containerRecommendations == null) {this.containerRecommendations = new java.util.ArrayList<io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder>();}
    io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder builder = new io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder(item);_visitables.get("containerRecommendations").add(index >= 0 ? index : _visitables.get("containerRecommendations").size(), builder);this.containerRecommendations.add(index >= 0 ? index : containerRecommendations.size(), builder); return (A)this;
  }
  public A setToContainerRecommendations(java.lang.Integer index,io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources item) {
    if (this.containerRecommendations == null) {this.containerRecommendations = new java.util.ArrayList<io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder>();}
    io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder builder = new io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder(item);
    if (index < 0 || index >= _visitables.get("containerRecommendations").size()) { _visitables.get("containerRecommendations").add(builder); } else { _visitables.get("containerRecommendations").set(index, builder);}
    if (index < 0 || index >= containerRecommendations.size()) { containerRecommendations.add(builder); } else { containerRecommendations.set(index, builder);}
     return (A)this;
  }
  public A addToContainerRecommendations(io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources... items) {
    if (this.containerRecommendations == null) {this.containerRecommendations = new java.util.ArrayList<io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder>();}
    for (io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources item : items) {io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder builder = new io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder(item);_visitables.get("containerRecommendations").add(builder);this.containerRecommendations.add(builder);} return (A)this;
  }
  public A addAllToContainerRecommendations(java.util.Collection<io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources> items) {
    if (this.containerRecommendations == null) {this.containerRecommendations = new java.util.ArrayList<io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder>();}
    for (io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources item : items) {io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder builder = new io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder(item);_visitables.get("containerRecommendations").add(builder);this.containerRecommendations.add(builder);} return (A)this;
  }
  public A removeFromContainerRecommendations(io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources... items) {
    for (io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources item : items) {io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder builder = new io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder(item);_visitables.get("containerRecommendations").remove(builder);if (this.containerRecommendations != null) {this.containerRecommendations.remove(builder);}} return (A)this;
  }
  public A removeAllFromContainerRecommendations(java.util.Collection<io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources> items) {
    for (io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources item : items) {io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder builder = new io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder(item);_visitables.get("containerRecommendations").remove(builder);if (this.containerRecommendations != null) {this.containerRecommendations.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromContainerRecommendations(java.util.function.Predicate<io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder> predicate) {
    if (containerRecommendations == null) return (A) this;
    final Iterator<io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder> each = containerRecommendations.iterator();
    final List visitables = _visitables.get("containerRecommendations");
    while (each.hasNext()) {
      io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildContainerRecommendations instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources> getContainerRecommendations() {
    return build(containerRecommendations);
  }
  public java.util.List<io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources> buildContainerRecommendations() {
    return build(containerRecommendations);
  }
  public io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources buildContainerRecommendation(java.lang.Integer index) {
    return this.containerRecommendations.get(index).build();
  }
  public io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources buildFirstContainerRecommendation() {
    return this.containerRecommendations.get(0).build();
  }
  public io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources buildLastContainerRecommendation() {
    return this.containerRecommendations.get(containerRecommendations.size() - 1).build();
  }
  public io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources buildMatchingContainerRecommendation(java.util.function.Predicate<io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder> predicate) {
    for (io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder item: containerRecommendations) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingContainerRecommendation(java.util.function.Predicate<io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder> predicate) {
    for (io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder item: containerRecommendations) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withContainerRecommendations(java.util.List<io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources> containerRecommendations) {
    if (this.containerRecommendations != null) { _visitables.get("containerRecommendations").removeAll(this.containerRecommendations);}
    if (containerRecommendations != null) {this.containerRecommendations = new java.util.ArrayList<io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder>(); for (io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources item : containerRecommendations){this.addToContainerRecommendations(item);}} else { this.containerRecommendations = null;} return (A) this;
  }
  public A withContainerRecommendations(io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources... containerRecommendations) {
    if (this.containerRecommendations != null) {this.containerRecommendations.clear();}
    if (containerRecommendations != null) {for (io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources item :containerRecommendations){ this.addToContainerRecommendations(item);}} return (A) this;
  }
  public java.lang.Boolean hasContainerRecommendations() {
    return containerRecommendations != null && !containerRecommendations.isEmpty();
  }
  public io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedPodResourcesFluent.ContainerRecommendationsNested<A> addNewContainerRecommendation() {
    return new io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedPodResourcesFluentImpl.ContainerRecommendationsNestedImpl();
  }
  public io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedPodResourcesFluent.ContainerRecommendationsNested<A> addNewContainerRecommendationLike(io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources item) {
    return new io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedPodResourcesFluentImpl.ContainerRecommendationsNestedImpl(-1, item);
  }
  public io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedPodResourcesFluent.ContainerRecommendationsNested<A> setNewContainerRecommendationLike(java.lang.Integer index,io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources item) {
    return new io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedPodResourcesFluentImpl.ContainerRecommendationsNestedImpl(index, item);
  }
  public io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedPodResourcesFluent.ContainerRecommendationsNested<A> editContainerRecommendation(java.lang.Integer index) {
    if (containerRecommendations.size() <= index) throw new RuntimeException("Can't edit containerRecommendations. Index exceeds size.");
    return setNewContainerRecommendationLike(index, buildContainerRecommendation(index));
  }
  public io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedPodResourcesFluent.ContainerRecommendationsNested<A> editFirstContainerRecommendation() {
    if (containerRecommendations.size() == 0) throw new RuntimeException("Can't edit first containerRecommendations. The list is empty.");
    return setNewContainerRecommendationLike(0, buildContainerRecommendation(0));
  }
  public io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedPodResourcesFluent.ContainerRecommendationsNested<A> editLastContainerRecommendation() {
    int index = containerRecommendations.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last containerRecommendations. The list is empty.");
    return setNewContainerRecommendationLike(index, buildContainerRecommendation(index));
  }
  public io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedPodResourcesFluent.ContainerRecommendationsNested<A> editMatchingContainerRecommendation(java.util.function.Predicate<io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder> predicate) {
    int index = -1;
    for (int i=0;i<containerRecommendations.size();i++) { 
    if (predicate.test(containerRecommendations.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching containerRecommendations. No match found.");
    return setNewContainerRecommendationLike(index, buildContainerRecommendation(index));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    RecommendedPodResourcesFluentImpl that = (RecommendedPodResourcesFluentImpl) o;
    if (containerRecommendations != null ? !containerRecommendations.equals(that.containerRecommendations) :that.containerRecommendations != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(containerRecommendations,  super.hashCode());
  }
  public class ContainerRecommendationsNestedImpl<N> extends io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesFluentImpl<io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedPodResourcesFluent.ContainerRecommendationsNested<N>> implements io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedPodResourcesFluent.ContainerRecommendationsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ContainerRecommendationsNestedImpl(java.lang.Integer index,io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources item) {
      this.index = index;
      this.builder = new io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder(this, item);
    }
    ContainerRecommendationsNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder(this);
    }
    io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) RecommendedPodResourcesFluentImpl.this.setToContainerRecommendations(index,builder.build());
    }
    public N endContainerRecommendation() {
      return and();
    }
    
  }
  
}

==> verticalpodautoscaler-model-v1-5.12.0-sources.jar: annotations/io/fabric8/verticalpodautoscaler/api/model/v1/RecommendedPodResourcesFluentImpl.java <==
package io.fabric8.verticalpodautoscaler.api.model.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public class RecommendedPodResourcesFluentImpl<A extends io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedPodResourcesFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedPodResourcesFluent<A>{
  public RecommendedPodResourcesFluentImpl() {
  }
  public RecommendedPodResourcesFluentImpl(io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedPodResources instance) {
    this.withContainerRecommendations(instance.getContainerRecommendations()); 
  }
  private java.util.List<io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder> containerRecommendations;
  public A addToContainerRecommendations(java.lang.Integer index,io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources item) {
    if (this.containerRecommendations == null) {this.containerRecommendations = new java.util.ArrayList<io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder>();}
    io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder builder = new io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder(item);_visitables.get("containerRecommendations").add(index >= 0 ? index : _visitables.get("containerRecommendations").size(), builder);this.containerRecommendations.add(index >= 0 ? index : containerRecommendations.size(), builder); return (A)this;
  }
  public A setToContainerRecommendations(java.lang.Integer index,io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources item) {
    if (this.containerRecommendations == null) {this.containerRecommendations = new java.util.ArrayList<io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder>();}
    io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder builder = new io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder(item);
    if (index < 0 || index >= _visitables.get("containerRecommendations").size()) { _visitables.get("containerRecommendations").add(builder); } else { _visitables.get("containerRecommendations").set(index, builder);}
    if (index < 0 || index >= containerRecommendations.size()) { containerRecommendations.add(builder); } else { containerRecommendations.set(index, builder);}
     return (A)this;
  }
  public A addToContainerRecommendations(io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources... items) {
    if (this.containerRecommendations == null) {this.containerRecommendations = new java.util.ArrayList<io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder>();}
    for (io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources item : items) {io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder builder = new io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder(item);_visitables.get("containerRecommendations").add(builder);this.containerRecommendations.add(builder);} return (A)this;
  }
  public A addAllToContainerRecommendations(java.util.Collection<io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources> items) {
    if (this.containerRecommendations == null) {this.containerRecommendations = new java.util.ArrayList<io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder>();}
    for (io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources item : items) {io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder builder = new io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder(item);_visitables.get("containerRecommendations").add(builder);this.containerRecommendations.add(builder);} return (A)this;
  }
  public A removeFromContainerRecommendations(io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources... items) {
    for (io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources item : items) {io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder builder = new io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder(item);_visitables.get("containerRecommendations").remove(builder);if (this.containerRecommendations != null) {this.containerRecommendations.remove(builder);}} return (A)this;
  }
  public A removeAllFromContainerRecommendations(java.util.Collection<io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources> items) {
    for (io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources item : items) {io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder builder = new io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder(item);_visitables.get("containerRecommendations").remove(builder);if (this.containerRecommendations != null) {this.containerRecommendations.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromContainerRecommendations(java.util.function.Predicate<io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder> predicate) {
    if (containerRecommendations == null) return (A) this;
    final Iterator<io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder> each = containerRecommendations.iterator();
    final List visitables = _visitables.get("containerRecommendations");
    while (each.hasNext()) {
      io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildContainerRecommendations instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources> getContainerRecommendations() {
    return build(containerRecommendations);
  }
  public java.util.List<io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources> buildContainerRecommendations() {
    return build(containerRecommendations);
  }
  public io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources buildContainerRecommendation(java.lang.Integer index) {
    return this.containerRecommendations.get(index).build();
  }
  public io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources buildFirstContainerRecommendation() {
    return this.containerRecommendations.get(0).build();
  }
  public io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources buildLastContainerRecommendation() {
    return this.containerRecommendations.get(containerRecommendations.size() - 1).build();
  }
  public io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources buildMatchingContainerRecommendation(java.util.function.Predicate<io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder> predicate) {
    for (io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder item: containerRecommendations) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingContainerRecommendation(java.util.function.Predicate<io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder> predicate) {
    for (io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder item: containerRecommendations) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withContainerRecommendations(java.util.List<io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources> containerRecommendations) {
    if (this.containerRecommendations != null) { _visitables.get("containerRecommendations").removeAll(this.containerRecommendations);}
    if (containerRecommendations != null) {this.containerRecommendations = new java.util.ArrayList(); for (io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources item : containerRecommendations){this.addToContainerRecommendations(item);}} else { this.containerRecommendations = null;} return (A) this;
  }
  public A withContainerRecommendations(io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources... containerRecommendations) {
    if (this.containerRecommendations != null) {this.containerRecommendations.clear();}
    if (containerRecommendations != null) {for (io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources item :containerRecommendations){ this.addToContainerRecommendations(item);}} return (A) this;
  }
  public java.lang.Boolean hasContainerRecommendations() {
    return containerRecommendations != null && !containerRecommendations.isEmpty();
  }
  public io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedPodResourcesFluent.ContainerRecommendationsNested<A> addNewContainerRecommendation() {
    return new io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedPodResourcesFluentImpl.ContainerRecommendationsNestedImpl();
  }
  public io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedPodResourcesFluent.ContainerRecommendationsNested<A> addNewContainerRecommendationLike(io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources item) {
    return new io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedPodResourcesFluentImpl.ContainerRecommendationsNestedImpl(-1, item);
  }
  public io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedPodResourcesFluent.ContainerRecommendationsNested<A> setNewContainerRecommendationLike(java.lang.Integer index,io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources item) {
    return new io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedPodResourcesFluentImpl.ContainerRecommendationsNestedImpl(index, item);
  }
  public io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedPodResourcesFluent.ContainerRecommendationsNested<A> editContainerRecommendation(java.lang.Integer index) {
    if (containerRecommendations.size() <= index) throw new RuntimeException("Can't edit containerRecommendations. Index exceeds size.");
    return setNewContainerRecommendationLike(index, buildContainerRecommendation(index));
  }
  public io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedPodResourcesFluent.ContainerRecommendationsNested<A> editFirstContainerRecommendation() {
    if (containerRecommendations.size() == 0) throw new RuntimeException("Can't edit first containerRecommendations. The list is empty.");
    return setNewContainerRecommendationLike(0, buildContainerRecommendation(0));
  }
  public io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedPodResourcesFluent.ContainerRecommendationsNested<A> editLastContainerRecommendation() {
    int index = containerRecommendations.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last containerRecommendations. The list is empty.");
    return setNewContainerRecommendationLike(index, buildContainerRecommendation(index));
  }
  public io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedPodResourcesFluent.ContainerRecommendationsNested<A> editMatchingContainerRecommendation(java.util.function.Predicate<io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder> predicate) {
    int index = -1;
    for (int i=0;i<containerRecommendations.size();i++) { 
    if (predicate.test(containerRecommendations.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching containerRecommendations. No match found.");
    return setNewContainerRecommendationLike(index, buildContainerRecommendation(index));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    RecommendedPodResourcesFluentImpl that = (RecommendedPodResourcesFluentImpl) o;
    if (containerRecommendations != null ? !containerRecommendations.equals(that.containerRecommendations) :that.containerRecommendations != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(containerRecommendations,  super.hashCode());
  }
  public class ContainerRecommendationsNestedImpl<N> extends io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesFluentImpl<io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedPodResourcesFluent.ContainerRecommendationsNested<N>> implements io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedPodResourcesFluent.ContainerRecommendationsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    ContainerRecommendationsNestedImpl(java.lang.Integer index,io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResources item) {
      this.index = index;
      this.builder = new io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder(this, item);
    }
    ContainerRecommendationsNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder(this);
    }
    io.fabric8.verticalpodautoscaler.api.model.v1.RecommendedContainerResourcesBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) RecommendedPodResourcesFluentImpl.this.setToContainerRecommendations(index,builder.build());
    }
    public N endContainerRecommendation() {
      return and();
    }
    
  }
  
}
